### Name: bio3d-package
### Title: Biological Structure Analysis
### Aliases: bio3d-package bio3d
### Keywords: documentation

### ** Examples

## Not run: 
##D lbio3d()  # list the functions within the package
##D 
##D ## See the individual functions for further documentation and examples.
##D #help(read.pdb)
##D 
##D ##-- Read a PDB file
##D pdb <- read.pdb(system.file("examples/1bg2.pdb", package="bio3d"))
##D 
##D ##-- Distance matrix
##D k <- dm(pdb, selection="calpha")
##D plot(k)
##D 
##D ## Extract SEQRES PDB sequence
##D s <- aa321(pdb$seqres)
##D 
##D ## write a FASTA format sequence file
##D write.fasta(seqs=s, id="seqres", file="eg.fa")
##D 
##D ## Reorient and write a new PDB file
##D xyz <- orient.pdb(pdb)
##D write.pdb(pdb, xyz = xyz, file = "mov1.pdb")
##D 
##D ##-- Torsion angle analysis and basic Ramachandran plot
##D tor <- torsion.pdb(pdb)
##D plot(tor$phi, tor$psi)
##D 
##D ##-- Secondary structure assignment with DSSP
##D sse <- dssp(pdb, resno=FALSE)
##D 
##D ## Plot of B-factor values along with secondary structure
##D plot.bio3d(pdb$atom[pdb$calpha,"b"], sse=sse, ylab="B-factor")
##D 
##D 
##D 
##D ##-- Read a FASTA alignment file
##D aln <- read.fasta( system.file("examples/kinesin_xray.fa",package="bio3d") )
##D 
##D ## Entropy score for alignment positions
##D h <- entropy(aln)    # see also the "conserv()" function
##D 
##D # Alignment consensus
##D con <- consensus(aln)
##D 
##D ## Plot of residue conservation (similarity) with secondary structure
##D plot.bio3d( conserv(aln)[!is.gap(aln$ali[1,])],  sse=sse )
##D 
##D ## Render the alignment as coloured HTML
##D aln2html(aln, append=FALSE, file="eg.html")
##D 
##D 
##D ##-- Read an alignment of sequences and their corresponding structures
##D aln  <- read.fasta( system.file("examples/kif1a.fa", package="bio3d") )
##D pdbs <- read.fasta.pdb( aln, pdbext = ".ent",
##D                pdb.path = system.file("examples",package="bio3d") )
##D 
##D ##-- DDM: Difference Distance Matrix
##D a <- dm(pdbs$xyz[2,])
##D b <- dm(pdbs$xyz[3,])
##D ddm <- a - b
##D plot(ddm,key=FALSE, grid=FALSE)
##D 
##D ##-- Superpose structures on non gap positions
##D gaps <- unique(which(is.na(pdbs$xyz) , arr.ind=TRUE)[,2])
##D gaps <- gap.inspect(pdbs$xyz)
##D 
##D xyz  <- fit.xyz( fixed  = pdbs$xyz[1,],
##D                 mobile = pdbs$xyz,
##D                 fixed.inds  = gaps$f.inds,
##D                 mobile.inds = gaps$f.inds )
##D 
##D ##-- RMSD
##D rmsd(pdbs$xyz[1,gaps$f.inds], pdbs$xyz[,gaps$f.inds])
##D rmsd(pdbs$xyz[1,gaps$f.inds], pdbs$xyz[,gaps$f.inds], fit=TRUE)
##D 
##D 
##D ##-- Rigid 'core' identification
##D aln <- read.fasta(system.file("examples/kinesin_xray.fa",package="bio3d"))
##D pdb.path = system.file("examples/",package="bio3d")
##D pdbs <- read.fasta.pdb(aln, pdb.path = pdb.path, pdbext = ".ent")
##D 
##D core <- core.find(pdbs,
##D                   #write.pdbs=TRUE,
##D                   rm.island=TRUE,
##D                   verbose=TRUE)
##D 
##D ## Plot core volume vs length
##D plot(core)
##D 
##D ## Core fit the structures (superpose on rigid zones)
##D xyz <- fit.xyz( fixed = pdbs$xyz[1,],
##D                 mobile = pdbs,
##D               #  full.pdbs = TRUE,
##D               #  pdb.path = pdb.path,
##D               #  pdbext = ".ent",
##D               #  outpath = "fitlsq/",
##D                 fixed.inds  = core$c0.5A.xyz,
##D                 mobile.inds = core$c0.5A.xyz)
##D 
##D ##-- PCA of structures
##D cut.seqs <- which(pdbs$id %in% c("d1n6mb_","d1ry6a_"))
##D # Ignore gap containing positions
##D gaps.res <- gap.inspect(pdbs$ali[-cut.seqs,])
##D gaps.pos <- gap.inspect(pdbs$xyz[-cut.seqs,])
##D 
##D ##-- Do PCA
##D pc.xray <- pca.xyz(xyz[-cut.seqs, gaps.pos$f.inds])
##D 
##D ## Plot results
##D plot(pc.xray)
##D 
##D #x11()
##D plot.pca.loadings(pc.xray$U)
##D 
##D ## Write PC trajectory
##D a <- mktrj.pca(pc.xray, pc=1, file="pc1.pdb",
##D                resno = pdbs$resno[1, gaps.res$f.inds],
##D                resid = aa123(pdbs$ali[1, gaps.res$f.inds]) )
##D 
##D 
##D ##-- Read a CHARMM/X-PLOR/NAMD trajectory file
##D trtfile <- system.file("examples/hivp.dcd", package="bio3d")
##D trj <- read.dcd(trtfile)
##D 
##D ## Read the starting PDB file to determine atom correspondence
##D pdbfile <- system.file("examples/hivp.pdb", package="bio3d")
##D pdb <- read.pdb(pdbfile)
##D 
##D ## Fit trj on PDB based on residues 23 to 31 and 84 to 87 in both chains
##D inds <- atom.select(pdb,"///23:31,84:87///CA/")
##D fit.xyz <- fit.xyz(pdb$xyz, trj, fixed.inds=inds$xyz, mobile.inds=inds$xyz)
##D 
##D ##-- RMSD of trj frames from PDB
##D r <- rmsd(a=pdb, b=fit.xyz)
##D 
##D ##-- PCA of trj
##D pc.trj <- pca.xyz(fit.xyz)
##D 
##D plot.pca.loadings(pc.trj)
##D 
##D ## Write PC trajectory for viewing in VMD
##D a <- mktrj.pca(pc.trj, pc=1, file="pc1_trj.pdb")
##D 
## End(Not run)
## other examples include: sdm, alignment, clustering etc...




