### Name: core.find
### Title: Identification of Invariant Core Positions
### Aliases: core.find
### Keywords: utilities

### ** Examples

## Not run: 
##D ##--  Read kinesin alignment and respective PDB structures
##D aln <- read.fasta(system.file("examples/kinesin_xray.fa",package="bio3d"))
##D pdb.path = system.file("examples",package="bio3d")
##D pdbs <- read.fasta.pdb(aln, pdb.path = pdb.path, pdbext = ".ent")
## End(Not run)

##-- Or read previously saved kinesin data
data(kinesin)
attach(kinesin)

## Raw RMSD before superposition
gaps <- gap.inspect(pdbs$xyz)
rmsd( pdbs$xyz[,gaps$f.inds] )

## RMSD after superposition on all positions
#rmsd(pdbs$xyz[,gaps$f.inds],fit=TRUE)

## Run core.find
core <- core.find(pdbs,
                  #write.pdbs = TRUE,
                  verbose=TRUE)

## Plot volume vs length
plot(core)

## Print 0.5A^3 core and store indices
inds <- print(core, vol=0.5)

## Fit structures onto first structure based on core indices (inds$xyz)
xyz <- fit.xyz( fixed = pdbs$xyz[1,],
                mobile = pdbs,
                fixed.inds  = inds$xyz,
                mobile.inds = inds$xyz)

# RMSD after superposition on 'core' positions
rmsd( xyz[,gaps$f.inds] )

## Not run: 
##D # Fit structures and write out 'full' structures
##D xyz <- fit.xyz( fixed = pdbs$xyz[1,],
##D                 mobile = pdbs,
##D                 fixed.inds  = core$c0.5A.xyz,
##D                 mobile.inds = core$c0.5A.xyz,
##D                 pdb.path = system.file("examples/",package="bio3d"),
##D                 pdbext = ".ent",
##D                 outpath = "fitlsq/",
##D                 full.pdbs = TRUE)
##D 
##D gaps  <- unique(which( is.na(xyz),arr.ind=TRUE )[,2])
##D 
##D # core fitted RMSD
##D rmsd(xyz[1,-gaps], xyz[,-gaps])
##D 
##D # original RMSD
##D rmsd(xyz[1,-gaps], xyz[,-gaps], fit=TRUE)
##D 
##D ##-- Try core.find() on a trajectory
##D trtfile <- system.file("examples/hivp.dcd", package="bio3d")
##D trj <- read.dcd(trtfile)
##D 
##D ## Read the starting PDB file to determine atom correspondence
##D pdbfile <- system.file("examples/hivp.pdb", package="bio3d")
##D pdb <- read.pdb(pdbfile)
##D 
##D ## select calpha coords from a manageable number of frames
##D ca.ind <- atom.select(pdb, "calpha")$xyz
##D frames <- seq(1, nrow(trj), by=10)
##D 
##D core <- core.find( trj[frames, ca.ind], write.pdbs=TRUE )
##D 
##D ## have a look at the various cores "vmd -m core_pruned/*.pdb"
##D 
##D ## Lets use a 6A^3 core cutoff
##D inds <- print(core, vol=6)
##D write.pdb(xyz=pdb$xyz[inds$xyz],resno=pdb$atom[inds$atom,"resno"], file="core.pdb")
##D 
##D ##- Fit trj onto starting structure based on core indices
##D xyz <- fit.xyz( fixed = pdb$xyz,
##D                mobile = trj,
##D                fixed.inds  = inds$xyz,
##D                mobile.inds = inds$xyz)
##D 
##D #write.pdb(pdb=pdb, xyz=xyz, file="new_trj.pdb")
## End(Not run)




