### Name: dm
### Title: Distance Matrix Analysis
### Aliases: dm dm.xyz
### Keywords: utilities

### ** Examples


##--- Distance Matrix Plot
pdb <- read.pdb( system.file("examples/d1bg2__.ent", package = "bio3d") )
k <- dm(pdb,selection="calpha")
filled.contour(k, nlevels = 4)

##--- DDM: Difference Distance Matrix
# Read aligned PDBs
aln <- read.fasta(system.file("examples/kif1a.fa",package="bio3d"))
pdb.path=paste(system.file(package="bio3d"),"/examples/",sep="")
m <- read.fasta.pdb(aln, pdb.path = pdb.path, pdbext = ".ent")

# Get distance matrix
a <- dm(m$xyz[2,])
b <- dm(m$xyz[3,])

# Calculate DDM
c <- a - b

# Plot DDM
plot(c,key=FALSE, grid=FALSE)

plot(c, axis.tick.space=10,
     resnum.1=m$resno[1,],
     resnum.2=m$resno[2,],
     grid.col="gray",
     xlab="Residue No. (1i6i)", ylab="Residue No. (1i5s)")

## Not run: 
##D ##-- Residue-wise distance matrix based on the
##D ##   minimal distance between all available atoms
##D l <- dm.xyz(pdb$xyz, grpby=pdb$atom[,"resno"], scut=3)
##D 
##D ##--- Extract all-atom contacts
##D pdb <- read.pdb( system.file("examples/d1bg2__.ent", package = "bio3d") )
##D l <- dm(pdb,selection="all")
##D l[upper.tri(l)]=NA  # make top diagonal NA
##D 
##D # Find residues with contacting atoms (<=5 Angstrom)
##D inds.stru <- which(l<=5, arr.ind=TRUE)   
##D 
##D # Find non-consecutive residues (>5 residues sequence separation)
##D seq.sep  <- abs(as.numeric(pdb$atom[inds.stru[,1],"resno"]) -
##D                as.numeric(pdb$atom[inds.stru[,2],"resno"]))
##D inds.seq <- which(seq.sep>5) # seperated by > 5 residues
##D 
##D # All-atom contacts (indices)
##D inds <- inds.stru[inds.seq,]
##D 
##D # All-atom contacts (now in terms of residue numbers)
##D tmp <- unique( paste(pdb$atom[inds[,1],"resno"],
##D                      pdb$atom[inds[,2],"resno"], sep="#") )
##D 
##D contacts <- matrix(as.numeric(unlist(strsplit(tmp,split="#"))),
##D                    ncol=2, byrow=TRUE )
##D 
##D # Plot residue contacts
##D freq  <- table(contacts)
##D xaxis <-as.vector(bounds(as.numeric(names(freq)))[,c(1,2)])
##D x11()
##D plot(freq, typ="h", xlab="Residue Number",
##D      xaxt="n",ylab="Number of Contacts" )
##D axis(1,at=xaxis,labels=xaxis)
## End(Not run)



