### Name: fit.xyz
### Title: Coordinate Superposition
### Aliases: fit.xyz rot.lsq
### Keywords: utilities

### ** Examples

## Not run: 
##D ##--- Read an alignment & Fit aligned structures
##D aln  <- read.fasta(system.file("examples/kif1a.fa",package="bio3d"))
##D pdb.path = system.file("examples",package="bio3d")
##D pdbs <- read.fasta.pdb(aln, pdb.path = pdb.path, pdbext = ".ent")
## End(Not run)

#-- OR Read previously saved kinesin data & Fit aligned structures
data(kinesin)
attach(kinesin)

gaps <- gap.inspect(pdbs$xyz)

xyz <- fit.xyz( fixed  = pdbs$xyz[1,],
               mobile = pdbs$xyz,
               fixed.inds  = gaps$f.inds,
               mobile.inds = gaps$f.inds )

# Use indices from 'core.find()' for improved fitting 
#core <- core.find(pdbs) # see ?core.find

# Superpose again this time outputing PDBs
## Not run: 
##D xyz <- fit.xyz( fixed = pdbs$xyz[1,],
##D                mobile = pdbs,
##D                fixed.inds  = gaps$f.inds,
##D                mobile.inds = gaps$f.inds,
##D                pdb.path = system.file("examples/",package="bio3d"),
##D                pdbext = ".ent",
##D                outpath = "rough_fit/",
##D                full.pdbs = TRUE)
##D 
##D ##--- Fit two PDBs
##D A <- read.pdb(system.file("examples/d1bg2__.ent",package="bio3d"))
##D A.ind <- atom.select(A, "///256:269///CA/")
##D 
##D B <- read.pdb(system.file("examples/d2kin.1.ent",package="bio3d"))
##D B.ind <- atom.select(B, "///257:270///CA/")
##D 
##D xyz <- fit.xyz(fixed=A$xyz, mobile=B$xyz,
##D                fixed.inds=A.ind$xyz,
##D                mobile.inds=B.ind$xyz)
##D 
##D # Write out moved PDB
##D C <- B; C$xyz = xyz
##D write.pdb(pdb=C, file = "moved.pdb")
## End(Not run)




