### Name: pca.xyz
### Title: Principal Component Analysis
### Aliases: pca.xyz
### Keywords: utilities multivariate

### ** Examples


## Not run: 
##D #-- Read kinesin alignment and structures
##D aln <- read.fasta(system.file("examples/kinesin_xray.fa",package="bio3d"))
##D pdb.path = system.file("examples/",package="bio3d")
##D pdbs <- read.fasta.pdb(aln, pdb.path = pdb.path, pdbext = ".ent")
##D 
##D # Find core
##D core <- core.find(pdbs,
##D                   #write.pdbs = TRUE,
##D                   verbose=TRUE)
##D 
##D # Fit structures onto sub 0.5A^3 core
##D xyz <- fit.xyz( fixed = pdbs$xyz[1,],
##D                 mobile = pdbs,
##D                 fixed.inds  = core$c0.5A.xyz,
##D                 mobile.inds = core$c0.5A.xyz) 
## End(Not run)

#-- OR Read previously saved kinesin data
data(kinesin)
attach(kinesin)

# Remove outlier structures from kinesin alignment
cut.seqs <- which(pdbs$id %in% c("d1n6mb_","d1ry6a_"))

# Ignore gap containing positions
gaps.res <- gap.inspect(pdbs$ali[-cut.seqs,])
gaps.pos <- gap.inspect(pdbs$xyz[-cut.seqs,])

#-- Do PCA
pc.xray <- pca.xyz(xyz[-cut.seqs, gaps.pos$f.inds])

# Plot results (conformer plots & scree plot)
plot(pc.xray)

## Plot atom wise loadings
plot.bio3d(pc.xray$au[,1], ylab="PC1 (A)")

#plot.bio3d(gaps.res$f.ind, pc.xray$au[,1],
#           xlab="Alignment Position", ylab="PC1 (A)")

## Plot loadings in relation to reference structure "d1bg2__"
res.ref <- which(!is.gap(pdbs$ali["d1bg2__",]))
res.ind <- which(res.ref %in% gaps.res$f.ind)
par(mfrow = c(3, 1), cex = 0.6, mar = c(3, 4, 1, 1))
plot.bio3d(res.ind, pc.xray$au[,1], sse=sse, ylab="PC1 (A)")
plot.bio3d(res.ind, pc.xray$au[,2], sse=sse, ylab="PC2 (A)")
plot.bio3d(res.ind, pc.xray$au[,3], sse=sse, ylab="PC3 (A)")


## Not run: 
##D # Write PC trajectory
##D a <- mktrj.pca(pc.xray, pc=1, file="pc1.pdb",
##D                resno = pdbs$resno[1, gaps.res$f.inds],
##D                resid = aa123(pdbs$ali[1, gaps.res$f.inds]) )
##D 
##D b <- mktrj.pca(pc.xray, pc=2, file="pc2.pdb",
##D                resno = pdbs$resno[1, gaps.res$f.inds],
##D                resid = aa123(pdbs$ali[1, gaps.res$f.inds]) )
##D 
##D c <- mktrj.pca(pc.xray, pc=3, file="pc3.pdb",
##D                resno = pdbs$resno[1, gaps.res$f.inds],
##D                resid = aa123(pdbs$ali[1, gaps.res$f.inds]) )
## End(Not run)




