### Name: torsion.xyz
### Title: Calculate Torsion/Dihedral Angles
### Aliases: torsion.xyz
### Keywords: utilities

### ** Examples

## Calculate torsions for cis & trans conformers
xyz <- rbind(c(0,-0.5,0,1,0,0,1,1,0,0,1.5,0),
             c(0,-0.5,0,1,0,0,1,1,0,2,1.5,0)-3)
cis.tor   <- torsion.xyz( xyz[1,] )
trans.tor <- torsion.xyz( xyz[2,] )
apply(xyz, 1, torsion.xyz)

plot(range(xyz), range(xyz), xlab="", ylab="", typ="n", axes=FALSE)
  apply(xyz, 1, function(x){
    lines(matrix(x, ncol=3, byrow=TRUE), lwd=4)
    points(matrix(x, ncol=3, byrow=TRUE), cex=2.5,
           bg="white", col="black", pch=21) } )
  
  text( t(apply(xyz, 1, function(x){
    apply(matrix(x, ncol=3, byrow=TRUE)[c(2,3),], 2, mean) })),
       labels=c(0,180), adj=-0.5, col="red")

## Not run: 
##D ##-- PDB torsion analysis
##D pdb <- read.pdb( system.file("examples/1bg2.pdb", package="bio3d") )
##D tor <- torsion.pdb(pdb)
##D ## basic Ramachandran plot
##D plot(tor$phi, tor$psi)
##D 
##D ## torsion analysis of a single coordinate vector 
##D inds <- atom.select(pdb,"calpha")
##D tor.ca <- torsion.xyz(pdb$xyz[inds$xyz], increment=3)
## End(Not run)

##-- Compare two PDBs to highlight interesting residues
aln <- read.fasta(system.file("examples/kif1a.fa",package="bio3d"))
pdb.path=paste(system.file(package="bio3d"),"/examples/",sep="")
m <- read.fasta.pdb(aln, pdb.path = pdb.path, pdbext = ".ent")
a <- torsion.xyz(m$xyz[2,],1)
b <- torsion.xyz(m$xyz[3,],1)
## Note the periodicity of torsion angles
d <- wrap.tor(a-b)
plot(m$resno[1,],d, typ="h")




